PagePerms

Struct PagePerms 

pub struct PagePerms(/* private fields */);
Uses Linux protection bits so mapping operations need no second permission model.

Implementations

Source

impl PagePerms

pub const READ: Self

Allows guest reads from a page.

pub const WRITE: Self

Allows guest writes to a page.

pub const EXEC: Self

Allows guest instruction fetches from a page.

pub const fn empty() -> Self

Creates permissions that deny all guest accesses.

pub const fn bits(self) -> u8

Returns the three permission bits used by generated code.

pub const fn from_bits(bits: u8) -> Self

Creates permissions and removes bits that this MMU does not support.

pub const fn contains(self, other: Self) -> bool

Tests whether all permissions in other are present.